/************************************************************************
     File:        MyWindow.cpp

     Author:     
                  Steven J Chenney, schenney@cs.wisc.edu
     Modifier
                  Yu-Chi Lai, yu-chi@cs.wisc.edu
     
     Comment:     For window for displaying the OpenGL operation
   
     Platform:    Visio Studio.Net 2003
*************************************************************************/

#include <Fl/Gl.h>
#include <Gl/Glu.h>

#include "MyWindow.h"

//************************************************************************
//
// * Constructor
//========================================================================
MyWindow::MyWindow(int width, int height, char* title) 
				: Fl_Gl_Window(width, height, title)
//========================================================================
{
	// Set up the GL window's properties
  mode(FL_RGB | FL_ALPHA | FL_DEPTH | FL_DOUBLE);
}


//************************************************************************
//
// * Destructor
//========================================================================
MyWindow::~MyWindow(void)
//========================================================================
{}


//************************************************************************
//
// * Initialize necessary GL operation
//========================================================================
void MyWindow::InitializeGL(void)
//========================================================================
{
	// Which color we should fill in the color buffer when glClear is called
  glClearColor(.1f, .1f, .1f, 1);
	// Enable the depth test of GL operation
  glEnable(GL_DEPTH_TEST);
}


//************************************************************************
//
// * Overwrite the window draw function
//========================================================================
void MyWindow::draw()
//========================================================================
{
 
  static bool firstTime = true; // Flag to control whether this is first time
  if (firstTime)   { // The first time, we need to set up the necessary GL parameters
    InitializeGL();
    firstTime = false;
  }// if

	// clear the color and depth buffer
  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);      

	//***********************************************************************************
	//
	// * Set up the GL camera
	//
	//***********************************************************************************
  // Set up the projection transformation
  glMatrixMode(GL_PROJECTION);
  glLoadIdentity();
  glFrustum(-1, 1, -1, 1, 1, 100);

	// Set up the Model view transformation
  glMatrixMode(GL_MODELVIEW);
  glLoadIdentity();
  gluLookAt(0, 0, 3, 0, 0, 0, 0, 1, 0);

  // draw something
  DrawCube();
}

//************************************************************************
//
// * Draw a cube which is center at (0, 0, 0)
//========================================================================
void MyWindow::DrawCube()
//========================================================================
{
  glBegin(GL_QUADS);
    // front
    glColor3f(1, 0, 0);
    glVertex3f(-1, 1, 1);
    glVertex3f(-1, -1, 1);
    glVertex3f(1, -1, 1);
    glVertex3f(1, 1, 1);

    // back
    glColor3f(0, 1, 0);
    glVertex3f(-1, 1, -1);
    glVertex3f(1, 1, -1);
    glVertex3f(1, -1, -1);
    glVertex3f(-1, -1, -1);

    // top
    glColor3f(0, 0, 1);
    glVertex3f(-1, 1, -1);
    glVertex3f(-1, 1, 1);
    glVertex3f(1, 1, 1);
    glVertex3f(1, 1, -1);

    // bottom
    glColor3f(1, 1, 0);
    glVertex3f(-1, -1, -1);
    glVertex3f(1, -1, -1);
    glVertex3f(1, -1, 1);
    glVertex3f(-1, -1, 1);

    // left
    glColor3f(0, 1, 1);
    glVertex3f(-1, 1, -1);
    glVertex3f(-1, -1, -1);
    glVertex3f(-1, -1, 1);
    glVertex3f(-1, 1, 1);

    // right
    glColor3f(1, 0, 1);
    glVertex3f(1, 1, 1);
    glVertex3f(1, -1, 1);
    glVertex3f(1, -1, -1);
    glVertex3f(1, 1, -1);
  glEnd();
}
